# Benford's law analysis

Benford's law is a digit-law, which states that the distribution of seperate digits in numbers follow a specific frequency.
This specific frequency is seen in many numerical datasets, as discovered by Simon Newcomb and Frank Benford.
You can find on [wikipedia] more information about this mysterious law.

Benford's law might be helpful to detect [fraud], do [science], or just investigate the [quality of data].

#### Installation
By ```pip install benfordslaw_analysis``` you will install the package.

#### Usage
Now you can do ```from benfordslaw_analysis import analysis``` to obtain the analysis script.
Here there is the class ```BenfordsLaw``` which you can get with ```analysis.BenfordsLaw```.
Now you can analyse your data.

For example, make a plot with Benford's law versus random data with:
```
from random import uniform
random_data = [uniform(-10, 10) for i in range(0,1000)]
bl = analysis.BenfordsLaw(random_data)
bl.plot_first_digit()
```
Note that we use the Euclidean distance between the digit frequency from Benford's law and your own data.

This package is still under development. More updates and documentation will come...


[wikipedia]: https://en.wikipedia.org/wiki/Benford%27s_law
[fraud]: https://www.journalofaccountancy.com/issues/2017/apr/excel-and-benfords-law-to-detect-fraud.html
[science]: https://towardsdatascience.com/benfords-law-in-the-gaia-universe-b5727db7a936
[quality of data]: https://watermark.silverchair.com/fdaa193.pdf?token=AQECAHi208BE49Ooan9kkhW_Ercy7Dm3ZL_9Cf3qfKAc485ysgAAAscwggLDBgkqhkiG9w0BBwagggK0MIICsAIBADCCAqkGCSqGSIb3DQEHATAeBglghkgBZQMEAS4wEQQMGsj0DVMi5YfOCU1YAgEQgIICekP4JYqohVuvNSsa89DWILIyFrOpiWuM8352LXgBsi9Ktfv5yHioW4MKjqsH5i2ELBUcnu75AKVZaNrlwOBBNkcQZQHnYR0EFydjya3D2xOX6dpXxj16NAhXcxbCzVD1q-052Bxfq2H6RWSorNkrRutjMR-rNsp95Ak4ld2RdCmQ48KCbiQ5E1I4Rwk0wtjmjfwLQq3M3zTFyZ_wGhCZeuTirSrBINdz1FThjUVOZTaHGLba6DeaiYaxZY9M1sPxMhMjAXY3qPkzXcMV8o1v0YCH1lDDcNTcCyM2m5Jynax1hGzJxIY7Bj_JWqBCTycVIa32Z_uzZIxgaiUuYgYWIsWRLg4BojbsaxynbTABq_8YcqVs33WGGylaQDnZdNywGltsJaB9BxIWM4-SIVSmNZhzf1egDU3oOk8uvxZmOpW4RBej4Pqd1DMCfM6gv3xg9H1zxVST8CoX8NYSafAqVAp0-_woul2HvQ8a66iqk4uSU4_MyFYBpWcKKIFSL4kx050brnRbwibFTEgIJtd2v9JPwd5G-VsWDdFyo3JCbQzyE5lLt6HqWz87ReSAStr_KYEjKb7n2sosiD_OlVA55_hJkDmPA6uzquyDn9NYKTGfFLyqeQH22EHkXmafEHWm5yePW1FzNKxyyGIqtoWMwG9mrxGEaxoh2tYS1ULw-jkP1rkFZaaKD4FKNRphHSMc-kvL6Re8I_H7TOXRi__eKA5K_Z2RkAOlPFqQSBexaxrCli5lP9zYRPR-OaxcdWraLbGerGLTbwuO8LK6wXmm9e2AGzj0XgU1AhX1BF1F87OmPOpVvyV55k_IjIK4XFVZLgCZvWbBmBBe3ns
